#!/bin/bash

#######################################################################
# Program: trackbuild.elm
# Purpose: Launch the build script via slacktrack/altertrack
# Author : Stuart Winter <stuart@armedslack.org>
#######################################################################

# Ensure slacktrack/altertrack is installed:
which altertrack >/dev/null 2>&1 || { echo "Cannot build without slacktrack" ; exit 1 ;}
TRACKTYPE=altertrack

# Paths to skeleton port's source & real Slackware source tree:
export CWD=$SLACKSOURCE/n/elm
export PORTCWD=$PWD

# Determine the CFLAGS for the known architectures:
case $PORTARCH in
   armv3)   export ARCH_CFLAGS="-O -march=armv3 -mtune=xscale" ;;
   powerpc) export ARCH_CFLAGS="-O" ;;
   sparc)   export ARCH_CFLAGS="-O" ;;
   alpha)   export ARCH_CFLAGS="-O" ;;
   x86_64)  export ARCH_CFLAGS="-O" ;;
   i486)    export ARCH_CFLAGS="-O" ;;
   mips)    export ARCH_CFLAGS="-O" ;;
   *)       export ARCH_CFLAGS="-O" ;;
esac

# If specified in slackdev.config, we'll delete the old copy of the
# package from our package store.
if [ "${DELETEOLDPKGS}" = "Yes" ]; then
   rm -f $PKGSTORE/$PKGSERIES/$PACKAGE-*.{tgz,txt}
fi

$TRACKTYPE ${ALTERTRACKOPTS} \
           -R${PORTCWD}/postbuild \
           -l${PBLOGS}/${PACKAGE}.log \
           -b${PKGSTORE}/${PKGSERIES} \
           -OcQp ${SLACKPACKAGE} ./${PACKAGE}.build ${VERSION}
